'use strict';
exports.handler = (event, context, callback) => {
    console.log(JSON.stringify(JSON.parse(event)))
    var eventObj=JSON.parse(event)
    const Core = require('@alicloud/pop-core');
    const axios = require('axios');

    var vpcClient = new Core({
        accessKeyId: context.credentials.accessKeyId,
        accessKeySecret: context.credentials.accessKeySecret,
        securityToken: context.credentials.securityToken, // use STS Token
        endpoint: 'https://vpc.'+eventObj.aliyunregionid+'.aliyuncs.com',
        apiVersion: '2016-04-28'
    });

    var TagClient = new Core({
        accessKeyId: context.credentials.accessKeyId,
        accessKeySecret: context.credentials.accessKeySecret,
        securityToken: context.credentials.securityToken, // use STS Token
        endpoint: 'https://tag.aliyuncs.com',
        apiVersion: '2018-08-28'
    });


    if(eventObj.data.resourceType=="ACS::VPC::NatGateway"&&eventObj.data.eventName=="Create")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "NatGatewayId": eventObj.data.resourceName
        }
        console.log(params)

        processTags(vpcClient, TagClient,"NatGateways", "NatGateway", params, eventObj.aliyunregionid, 'DescribeNatGateways', 'NatGateway', eventObj.data.resourceName, callback)

        
    }else if(eventObj.data.resourceType=="ACS::VPNGateway::VpnGateway"&&eventObj.data.eventName=="Create")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "VpnGatewayId": eventObj.data.resourceName
        }
        
        console.log(params)

        processTags(vpcClient, TagClient, "VpnGateways", "VpnGateway", params, eventObj.aliyunregionid, 'DescribeVpnGateways', 'VpnGateway', eventObj.data.resourceName, callback)
        
    }else if(eventObj.data.resourceType=="ACS::ECS::Instance;ACS::EIP::EipAddress"
            &&eventObj.data.eventName=="AssociateEipAddress"
            &&eventObj.data.requestParameters.Mode=="NAT")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "NatGatewayId": eventObj.data.requestParameters.InstanceId
        }

        console.log(params)

        processTags(vpcClient, TagClient,"NatGateways", "NatGateway", params, eventObj.aliyunregionid, 'DescribeNatGateways', 'eip', eventObj.data.requestParameters.AllocationId, callback)
        
    }else if(eventObj.data.resourceType=="ACS::VPC::VSwitch;ACS::VPC::VPC"
            &&eventObj.data.eventName=="CreateVSwitch")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "VSwitchId": eventObj.data.responseElements.VSwitchId
        }

        console.log(params)

        processTags(vpcClient, TagClient, "VSwitches", "VSwitch", params, eventObj.aliyunregionid, 'DescribeVSwitches', 'vswitch', eventObj.data.responseElements.VSwitchId, callback)
        
    }else if(eventObj.data.resourceType=="ACS::VPC::RouteTable;ACS::VPC::VPC"
            &&eventObj.data.eventName=="CreateRouteTable")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "RouteTableId": eventObj.data.responseElements.RouteTableId
        }

        console.log(params)

        processTags(vpcClient, TagClient, "RouterTableList", "RouterTableListType", params, eventObj.aliyunregionid, 'DescribeRouteTableList', 'routetable', eventObj.data.responseElements.RouteTableId, callback)
        
    }else if(eventObj.data.resourceType=="ACS::VPC::VPC"
            &&eventObj.data.eventName=="CreateIpv6Gateway")
    {
        var params = {
            "RegionId": eventObj.aliyunregionid,
            "Ipv6GatewayId": eventObj.data.responseElements.Ipv6GatewayId
        }

        console.log(params)

        processTags(vpcClient, TagClient, "Ipv6Gateways", "Ipv6Gateway", params, eventObj.aliyunregionid, 'DescribeIpv6Gateways', 'ipv6gateway', eventObj.data.responseElements.Ipv6GatewayId, callback)
        
    } 
    else{
        callback()
    }

    

}

function processTags(vpcClient, tagClient, aName, eName, params,regionId, action, resourceType, resourceId, callback)
{

            var requestOption = {
                method: 'POST'
            };

            vpcClient.request(action, params, requestOption).then((resourceResult) => {
                console.log(params)
                console.log(JSON.stringify(resourceResult));
                getVPCs(vpcClient, regionId, resourceResult[aName][eName][0].VpcId).then((VPCResult) => {
                    console.log(JSON.stringify(VPCResult));
                    var vpc=VPCResult.Vpcs.Vpc[0];
                    var arn="arn:acs:vpc"+":"+regionId+":*:"+resourceType+"/"+resourceId
                    tagResources(tagClient, regionId, arn, vpc.Tags).then((tagResult) => {
                        console.log(JSON.stringify(tagResult));
                        callback()
                    }, (ex) => {
                    console.log(ex);
                    callback()
                    }
                    
                    )
                }, (ex) => {
                    console.log(ex);
                    callback()
                })
            }, (ex) => {
                console.log(ex);
                callback()
            })

}

function getVPCs(vpcClient, RegionId, vpcId) {
    var params = {
    "VpcId": vpcId,
    "RegionId": RegionId
    }

    console.log(params)

    var requestOption = {
        method: 'POST'
    };

    return vpcClient.request('DescribeVpcs', params, requestOption)
}

function tagResources(tagClient, regionid, arn, tags)
{
      var tagObj={}
    for(var tag of tags.Tag)
    {
        tagObj[tag.Key]=tag.Value
    }

    var params = {
        "ResourceARN": [
            arn
        ],
        "RegionId": regionid,
        "Tags": JSON.stringify(tagObj)
    }
    console.log(params)
    var requestOption = {
    method: 'POST'
    };

    return tagClient.request('TagResources', params, requestOption)
}